rdflib.plugins.parsers package
==============================

Submodules
----------

rdflib.plugins.parsers.RDFVOC module
------------------------------------

.. automodule:: rdflib.plugins.parsers.RDFVOC
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.plugins.parsers.jsonld module
------------------------------------

.. automodule:: rdflib.plugins.parsers.jsonld
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.plugins.parsers.notation3 module
---------------------------------------

.. automodule:: rdflib.plugins.parsers.notation3
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.plugins.parsers.nquads module
------------------------------------

.. automodule:: rdflib.plugins.parsers.nquads
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.plugins.parsers.ntriples module
--------------------------------------

.. automodule:: rdflib.plugins.parsers.ntriples
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.plugins.parsers.rdfxml module
------------------------------------

.. automodule:: rdflib.plugins.parsers.rdfxml
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.plugins.parsers.trig module
----------------------------------

.. automodule:: rdflib.plugins.parsers.trig
   :members:
   :undoc-members:
   :show-inheritance:

rdflib.plugins.parsers.trix module
----------------------------------

.. automodule:: rdflib.plugins.parsers.trix
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: rdflib.plugins.parsers
   :members:
   :undoc-members:
   :show-inheritance:
